@@ -13,5 +13,8 @@ pub use swap::swap;
 mod drain_filter;
 pub use drain_filter::drain_filter;
 
+mod log_formatter;
+pub use log_formatter::LogFormatter;
+
 #[cfg(feature = "async")]
 pub mod futures;
